@@ -1,4 +1,4 @@
-# $Id: /mirror/coderepos/lang/perl/Cache-Memcached-libmemcached/trunk/lib/Cache/Memcached/libmemcached.pm 50653 2008-04-17T15:58:23.005045Z daisuke  $
+# $Id: /mirror/coderepos/lang/perl/Cache-Memcached-libmemcached/trunk/lib/Cache/Memcached/libmemcached.pm 50667 2008-04-17T23:37:58.026202Z daisuke  $
 #
 # Copyright (c) 2008 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -11,7 +11,7 @@ use Carp qw(croak);
 use Scalar::Util qw(weaken);
 use Storable ();
 
-our $VERSION = '0.02004';
+our $VERSION = '0.02005';
 
 use constant HAVE_ZLIB    => eval { require Compress::Zlib } && !$@;
 use constant F_STORABLE   => 1;
@@ -34,9 +34,9 @@ BEGIN
     }
 
     # proxy these methods
-    foreach my $method qw(delete set add replace prepend append cas) {
+    foreach my $method qw(set add replace prepend append cas) {
         eval <<"        EOSUB";
-            sub $method { shift->memcached_$method(\@_) }
+            sub $method { shift->memcached_$method(\@_[0, 1], int(\$_[2] || 0)) }
         EOSUB
         die if $@;
     }
@@ -146,6 +146,8 @@ sub _mk_callbacks
     return ($deflate, $inflate);
 }
 
+sub delete { shift->memcached_delete($_[0], int($_[1] || 0)) }
+
 sub incr
 {
     my $self = shift;
